MethodChannelUrlLauncher class

An implementation of UrlLauncherPlatform that uses method channels.

Inheritance

Constructors

MethodChannelUrlLauncher()

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkDelegate → LinkDelegate?
The delegate used by the Link widget to build itself.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canLaunch(String url) → Future<bool>
Returns true if this platform is able to launch url.
override
closeWebView() → Future<void>
Closes the web view, if one was opened earlier by launchUrl.
override
launch(String url, {required bool useSafariVC, required bool useWebView, required bool enableJavaScript, required bool enableDomStorage, required bool universalLinksOnly, required Map<String, String> headers, String? webOnlyWindowName}) → Future<bool>
Passes url to the underlying platform for handling.
override
launchUrl(String url, LaunchOptions options) → Future<bool>
Passes url to the underlying platform for handling.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsCloseForMode(PreferredLaunchMode mode) → Future<bool>
Returns true if the given launch mode can be closed with closeWebView.
inherited
supportsMode(PreferredLaunchMode mode) → Future<bool>
Returns true if the given launch mode is supported by the current implementation.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited